CloudMediaListOptions class

Constructors

CloudMediaListOptions({CloudMediaType? type, int limit = 50, int offset = 0, DateTime? startDate, DateTime? endDate, String? searchQuery, String orderBy = 'createdAt', bool descending = true})
const

Properties

descending bool
final
endDate DateTime?
final
hashCode int
The hash code for this object.
no setterinherited
limit int
final
offset int
final
orderBy String
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
searchQuery String?
final
startDate DateTime?
final
type CloudMediaType?
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited