ErrorMessages class
Properties
- hashCode → int
-
The hash code for this object.
no setterinherited
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited
Constants
- backgroundRemovalTimeout → const String
- compressionFailed → const String
- downloadFailed → const String
- fileTooLarge → const String
- mediaNotFound → const String
- networkError → const String
- notInitialized → const String
- permissionDenied → const String
- permissionPermanentlyDenied → const String
- selectionLimitExceeded → const String
- thumbnailFailed → const String
- unsupportedFileType → const String
- uploadFailed → const String