FileConstants class
Properties
- hashCode → int
-
The hash code for this object.
no setterinherited
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited
Constants
-
audioExtensions
→ const List<
String> - cacheBoxName → const String
- cacheDirectory → const String
- defaultMaxSelection → const int
-
documentExtensions
→ const List<
String> - hardMaxSelection → const int
-
imageExtensions
→ const List<
String> - maxAudioSizeBytes → const int
- maxCacheAgeDays → const int
- maxCacheSizeBytes → const int
- maxDocumentSizeBytes → const int
- maxImageSizeBytes → const int
- maxVideoSizeBytes → const int
- thumbnailsDirectory → const String
- uploadsBoxName → const String
-
videoExtensions
→ const List<
String>