UIConstants class
Properties
- hashCode → int
-
The hash code for this object.
no setterinherited
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited
Constants
- defaultBorderRadius → const double
- defaultPadding → const double
- gridCrossAxisCount → const int
- gridSpacing → const double
- largeBorderRadius → const double
- largePadding → const double
- longAnimationDuration → const Duration
- mediumAnimationDuration → const Duration
- shortAnimationDuration → const Duration
- smallPadding → const double