CacheEntry class

Constructors

CacheEntry({required String key, required String localPath, required int size, required DateTime cachedAt, required DateTime lastAccessedAt})
const
CacheEntry.fromJson(Map<String, dynamic> json)
factory

Properties

cachedAt DateTime
final
hashCode int
The hash code for this object.
no setterinherited
key String
final
lastAccessedAt DateTime
final
localPath String
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
size int
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() Map<String, dynamic>
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited