compress property
bool
get
compress
Whether automatic compression should run at all for this profile.
Implementation
bool get compress => this != CompressionProfile.none;
Whether automatic compression should run at all for this profile.
bool get compress => this != CompressionProfile.none;