CacheService class

Constructors

CacheService({required CloudMediaConfig config})

Properties

config CloudMediaConfig
final
hashCode int
The hash code for this object.
no setterinherited
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

clear() Future<void>
Alias used by provider dispose
clearAll() Future<void>
dispose() Future<void>
get(String key) Future<String?>
getCacheSize() Future<int>
initialize() Future<void>
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
remove(String key) Future<void>
set(String key, String filePath, int size) Future<void>
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited