QueuePriority enum

Inheritance
Available extensions

Values

critical → const QueuePriority
high → const QueuePriority
normal → const QueuePriority
low → const QueuePriority
background → const QueuePriority

Properties

hashCode int
The hash code for this object.
no setterinherited
index int
A numeric identifier for the enumerated value.
no setterinherited
name String

Available on Enum, provided by the EnumName extension

The name of the enum value.
no setter
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
value int

Available on QueuePriority, provided by the QueuePriorityValue extension

no setter

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited

Constants

values → const List<QueuePriority>
A constant List of the values in this enum, in order of their declaration.