StorageQueueService class
Properties
- hashCode → int
-
The hash code for this object.
no setterinherited
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited
Static Methods
-
cancelUpload(
String mediaId) → void -
pauseUpload(
String mediaId) → void -
resumeUpload(
String mediaId) → void -
uploadFile(
{required File file, required String storagePath, required String mediaId, required String userId, VoidCallback? onComplete, void onProgress(double)?}) → Future< void>