UploadProgressData class

Constructors

UploadProgressData({required double progress, required int uploaded, required int total, String status = 'uploading'})
const

Properties

hashCode int
The hash code for this object.
no setterinherited
progress double
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
status String
final
total int
final
uploaded int
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited