CloudHlsPlayerScreen class

Full-screen HLS (m3u8) video player screen.

Use this when your CloudMediaItem.downloadUrl is an .m3u8 stream URL. For regular mp4/mov uploads use CloudVideoPlayerScreen instead.

// From a CloudMediaItem with an HLS stream URL
Navigator.of(context).push(MaterialPageRoute(
  builder: (_) => CloudHlsPlayerScreen(media: item),
));

// From a raw m3u8 URL
Navigator.of(context).push(MaterialPageRoute(
  builder: (_) => CloudHlsPlayerScreen.fromUrl(
    url: 'https://example.com/stream.m3u8',
    title: 'Live Stream',
  ),
));
Inheritance

Constructors

CloudHlsPlayerScreen({Key? key, required String hlsUrl, String title = '', bool autoPlay = true})
const
CloudHlsPlayerScreen.fromMedia(CloudMediaItem media)
Convenience constructor for a CloudMediaItem whose downloadUrl is m3u8.
factory
CloudHlsPlayerScreen.fromUrl({required String url, String title = ''})
Convenience constructor for a raw m3u8 URL.
factory

Properties

autoPlay bool
final
hashCode int
The hash code for this object.
no setterinherited
hlsUrl String
final
key Key?
Controls how one widget replaces another widget in the tree.
finalinherited
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
title String
final

Methods

createElement() StatefulElement
Creates a StatefulElement to manage this widget's location in the tree.
inherited
createState() State<CloudHlsPlayerScreen>
Creates the mutable state for this widget at a given location in the tree.
override
debugDescribeChildren() List<DiagnosticsNode>
Returns a list of DiagnosticsNode objects describing this node's children.
inherited
debugFillProperties(DiagnosticPropertiesBuilder properties) → void
Add additional properties associated with the node.
inherited
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toDiagnosticsNode({String? name, DiagnosticsTreeStyle? style}) DiagnosticsNode
Returns a debug representation of the object that is used by debugging tools and by DiagnosticsNode.toStringDeep.
inherited
toString({DiagnosticLevel minLevel = DiagnosticLevel.info}) String
A string representation of this object.
inherited
toStringDeep({String prefixLineOne = '', String? prefixOtherLines, DiagnosticLevel minLevel = DiagnosticLevel.debug, int wrapWidth = 65}) String
Returns a string representation of this node and its descendants.
inherited
toStringShallow({String joiner = ', ', DiagnosticLevel minLevel = DiagnosticLevel.debug}) String
Returns a one-line detailed description of the object.
inherited
toStringShort() String
A short, textual description of this widget.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited