FileUtils class
Properties
- hashCode → int
-
The hash code for this object.
no setterinherited
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited
Static Methods
-
deleteFile(
String filePath) → Future< void> -
formatFileSize(
int bytes) → String -
getFileExtension(
String fileName) → String -
getFileNameWithoutExtension(
String fileName) → String -
getFileSize(
File file) → Future< int> -
getMimeType(
String fileName) → String -
isAudio(
String fileName) → bool -
isImage(
String fileName) → bool -
isPdf(
String fileName) → bool -
isVideo(
String fileName) → bool