UploadTask class
Constructors
- UploadTask({required String id, required String mediaId, required String localPath, required String storagePath, required CloudMediaType type, int retryCount = 0, required DateTime createdAt, DateTime? lastAttemptAt, UploadTaskStatus taskStatus = UploadTaskStatus.pending})
-
const
-
UploadTask.fromJson(Map<
String, dynamic> json) -
factory
Properties
- createdAt → DateTime
-
final
- hashCode → int
-
The hash code for this object.
no setterinherited
- id → String
-
final
- lastAttemptAt → DateTime?
-
final
- localPath → String
-
final
- mediaId → String
-
final
- retryCount → int
-
final
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
- storagePath → String
-
final
- taskStatus → UploadTaskStatus
-
final
- type → CloudMediaType
-
final
Methods
-
copyWith(
{String? id, String? mediaId, String? localPath, String? storagePath, CloudMediaType? type, int? retryCount, DateTime? createdAt, DateTime? lastAttemptAt, UploadTaskStatus? taskStatus}) → UploadTask -
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toJson(
) → Map< String, dynamic> -
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited