UploadService class
Constructors
- UploadService({required CloudMediaConfig config})
Properties
- config → CloudMediaConfig
-
final
- hashCode → int
-
The hash code for this object.
no setterinherited
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
Methods
-
cancelUpload(
String uploadId) → void -
completeUpload(
String uploadId) → void -
createCancelToken(
String uploadId) → CancelToken -
dispose(
) → void -
failUpload(
String uploadId) → void -
getUploadProgress(
String uploadId) → Stream< UploadProgressData> -
isCancelled(
String uploadId) → bool -
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
pickMedia(
{required CloudMediaType type, required int maxCount}) → Future< List< PickedFile> > -
toString(
) → String -
A string representation of this object.
inherited
-
updateProgress(
String uploadId, double progress, int uploaded, int total) → void
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited