CloudMediaImageEditor class
Properties
-
hashCode
→ int
-
The hash code for this object.
no setterinherited
-
runtimeType
→ Type
-
A representation of the runtime type of the object.
no setterinherited
Methods
-
noSuchMethod(Invocation invocation)
→ dynamic
-
Invoked when a nonexistent method or property is accessed.
inherited
-
toString()
→ String
-
A string representation of this object.
inherited
Static Methods
-
edit({required BuildContext context, required String imagePath, ImageEditorConfig config = const ImageEditorConfig(enableText: false, cropOptions: CropOptionConfig(enableFree: true, enable16By9: true, enable5By4: true, enable1By1: true), rotateOptions: RotateOptionConfig(enableFree: true, enableFixed: true), topToolbar: TopToolbarConfig(titleText: 'Edit Image', confirmText: 'Done'), compression: ImageCompressionConfig(enabled: true, scale: 1.0))})
→ Future<String?>
-